@@ -3,7 +3,7 @@ test_common_validations.py
 
 Tests common validations that are shared across X12 transaction sets.
 """
-from x12.io import X12ModelReader
+from linuxforhealth.x12.io import X12ModelReader
 import pytest
 
 
