@@ -5,14 +5,14 @@ Tests support functions.
 """
 import pytest
 import datetime
-from x12.support import (
+from linuxforhealth.x12.support import (
     is_x12_data,
     is_x12_file,
     parse_x12_date,
     parse_interchange_date,
     count_segments,
 )
-from x12.io import X12ModelReader
+from linuxforhealth.x12.io import X12ModelReader
 
 
 @pytest.mark.parametrize(
@@ -68,6 +68,7 @@ def test_parser_interchange_date():
 
 def test_parse_x12_date():
     assert parse_x12_date("20120501") == datetime.date(2012, 5, 1)
+    assert parse_x12_date("201205011010") == datetime.datetime(2012, 5, 1, 10, 10)
     assert parse_x12_date("") is None
     assert parse_x12_date(None) is None
 
